#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-info
version:              0.2.1
visibility:           public
id:                   network-info-0.2.1-1ELhTO025aF3xbpJiZvy4m
key:                  network-info-0.2.1-1ELhTO025aF3xbpJiZvy4m
license:              BSD-3-Clause
maintainer:           Jacob Stanley <jacob@stanley.io>
author:               Jacob Stanley
homepage:             http://github.com/jacobstanley/network-info
synopsis:             Access the local computer'\''s basic network configuration
description:
    This library provides simple read-only access to the
    local computer'\''s networking configuration. It is
    currently capable of getting a list of all the network
    interfaces and their respective IPv4, IPv6 and MAC
    addresses.

    network-info has been tested and is known to work on
    Ubuntu, FreeBSD, NetBSD, Mac OS and Windows.

category:             Network
abi:                  d03164de69ebfec945aa2f1226dff4ad
exposed:              True
exposed-modules:      Network.Info
import-dirs:          /usr/lib/ghc-9.6.6/site-local/network-info-0.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/network-info-0.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/network-info-0.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-info
hs-libraries:         HSnetwork-info-0.2.1-1ELhTO025aF3xbpJiZvy4m
depends:              base-4.18.2.1
haddock-interfaces:
    /usr/share/doc/haskell-network-info/html/network-info.haddock

haddock-html:         /usr/share/doc/haskell-network-info/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

